betty.plugin.lazy module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.plugin.lazy module

Lazily load plugins.

class betty.plugin.lazy.LazyPluginRepositoryBase

  Bases: `PluginRepository`[`_PluginT`], `Generic`[`_PluginT`]

  Lazily load plugins.

  __init__()
  async get(plugin_id: str) → type[_PluginT]

    Get a single plugin by its ID.

    Raises:

      PluginNotFound – if no plugin can be found for the given ID.